@@ -77,8 +77,10 @@ class QLDBDriver:
         for id in ids:
             statement = f"FROM {table_name} WHERE {identifier} = {id[identifier]} REMOVE {attribute_name}"
 
-            self.qldb_driver.execute_lambda(lambda x: self.execute(x, statement))
-
+            try:
+                self.qldb_driver.execute_lambda(lambda x: self.execute(x, statement))
+            except:
+                pass
 
     def list_tables(self):
         collection = []
